logger

package
v0.0.0-...-5cb58b4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 20, 2018 License: MIT Imports: 14 Imported by: 0

Documentation

Overview

Package logger is used to store details of events in the node. Events can be categorized by Debug, Info, Error, Fatal, and Panic.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateProductionLogger

func CreateProductionLogger(dir string, lvl zapcore.Level) *zap.Logger

CreateProductionLogger returns a log config for the passed directory with the given LogLevel and customizes stdout for pretty printing.

func CreateTestLogger

func CreateTestLogger() *zap.Logger

CreateTestLogger creates a logger that directs output to PrettyConsole configured for test output.

func Debug

func Debug(args ...interface{})

Debug logs an debug message using Sprint.

func Debugw

func Debugw(msg string, keysAndValues ...interface{})

Debugw logs a debug message and any additional given information.

func Error

func Error(args ...interface{})

Error logs an error message using Sprint.

func Errorw

func Errorw(msg string, keysAndValues ...interface{})

Errorw logs an error message, any additional given information, and includes stack trace.

func Fatal

func Fatal(args ...interface{})

Fatal logs a fatal message then exits the application using Sprint.

func Info

func Info(args ...interface{})

Info logs an info message using Sprint.

func Infof

func Infof(format string, values ...interface{})

Infof formats and then logs the message before panicking.

func Infow

func Infow(msg string, keysAndValues ...interface{})

Infow logs an info message and any additional given information.

func Panic

func Panic(args ...interface{})

Panic logs a panic message then panics using Sprint.

func PanicIf

func PanicIf(err error)

PanicIf logs the error if present.

func Panicf

func Panicf(format string, values ...interface{})

Panicf formats and then logs the message before panicking.

func SetLogger

func SetLogger(zl *zap.Logger)

SetLogger sets the internal logger to the given input.

func Sync

func Sync() error

Sync flushes any buffered log entries.

func Warn

func Warn(args ...interface{})

Warn logs a message at the warn level using Sprint.

func WarnIf

func WarnIf(err error)

WarnIf logs the error if present.

func Warnw

func Warnw(msg string, keysAndValues ...interface{})

Warnw logs a debug message and any additional given information.

Types

type Logger

type Logger struct {
	*zap.SugaredLogger
}

Logger holds a field for the logger interface.

func (*Logger) Write

func (l *Logger) Write(b []byte) (int, error)

Write logs a message at the Info level and returns the length of the given bytes.

type PrettyConsole

type PrettyConsole struct {
	zap.Sink
}

PrettyConsole wraps a Sink (Writer, Syncer, Closer), usually stdout, and formats the incoming json bytes with colors and white space for readability before passing on to the underlying Writer in Sink.

func (PrettyConsole) Write

func (pc PrettyConsole) Write(b []byte) (int, error)

Write reformats the incoming json bytes with colors, newlines and whitespace for better readability in console.

Jump to